# =====================================================================
# wwwfilter.awk: pick selected entries from the CSA_RPC_WWW file.
#
# Copyright (c) 2003 Carlo Strozzi
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# =====================================================================
# $Id: cgilib.awk,v 1.5 2003/05/07 09:11:26 carlo Exp $

# =====================================================================
# Notes:
#
# A pattern always implies a leading "WWW_". File patterns have an
# implicit ".*F" trailer appended. Variables that begin with either
# "CSA_" or "HTTP_" are printed regardless of the specified pattern.
# If the pattern contains a trailing newline matching directive "$", it
# will be mangled to also output files and list names, assuming that
# that is the desired behaviour. For this reason, if an end-of-line
# directive should always only be specified at the end of the pattern,
# not in other positions of it. Otherwise files and list names may not
# match.
#
# Example:
#
#    scanning the pyx2awk.rc sample file with the following pattern:
#
#      (3_1_1_4_1[^1-9]*|[12]_1(_[1-9])?)$
#
#    will produce the following output:
#
#      'CSA_RPC_ACTION'=( 'GET')
#      'WWW_1_1_2'=( '...')
#      'WWW_1_1_3'=( '...')
#      'WWW_2_1'=( 'pippo')
#      'WWW_3_1_1_4_1_N'=( 'orazio')
#      'WWW_3_1_1_4_1'=( 'clarabella')
#      'WWW_1_1_1'=( 'HTTP_AUTHORIZATION' 'CSA_RPC_ACTION')
#
# =====================================================================

BEGIN {

   #pattern = "3[^1-9]"			# This is the passed argument.

   if (sub(/\$$/, "", pattern)) {
      file_pattern = "csaMkTemp WWW_" pattern "[_]?F"
      pattern = "^('WWW_" pattern "($|'|[_]?N)|'CSA_|'HTTP_)"
   }
   else {
      file_pattern = "csaMkTemp WWW_" pattern ".*F"
      pattern = "^('WWW_" pattern "|'CSA_|'HTTP_)"
   }

   # *Always* initialize variables in the BEGIN{} block.
   prt = 0
}

/^('WWW_|csaMkTemp)/ { prt = 0 }

$0 ~ pattern { prt = 1 }

$0 ~ file_pattern {

     print
     getline
     print
     prt = 1
     next
}

prt { print }

# =====================================================================
# End of wwwfilter.awk
# =====================================================================
