# =====================================================================
# AWK functions for CSA.
#
# Copyright (c) 2001,2002,2003 Carlo Strozzi
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License 
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# =====================================================================
# $Id: _rcassign.awk,v 1.1 2004/08/08 21:15:38 carlo Exp $
# =====================================================================
# boolean _rcassign(string name,\
#	string value [, string ofile, int append])
#
# Turn the passed name/value pair into a valid rc(1) assignment in
# the form: name=(value_1 value_2 ... value_n). Value is split on
# octal "\001" to cope with rc(1) lists. The resulting assignment is
# then printed to 'ofile', properly escaped for rc(1). If 'append'
# is '1' then 'name' is considered an rc(1) list to be appended to
# rather than to be defined from scratch. If append is equal to '2'
# then the resulting string will be attached to, rather than appended,
# i.e. it will have one single element.
# =====================================================================

function _rcassign(name,value,ofile,append,		i,a,j,s) {

  i=j=0
  if (ofile == _NULL) ofile = _STDOUT

  # Help rc(1) handle non-conventional variable names.
  name = _rcescape(name,1)
  if (name == "''") return _EINVAL

  if (append) printf("%s=($%s",name,name) >> ofile
  else printf("%s=(",name) >> ofile

  if (append == _O_ATTACH) s = "^"
  else s = " "

  # Split on "\001" to cope with rc(1) lists.

  if ((i = split(value,a,"\001"))) { 
     for (j=1; j<=i; j++) printf("%s%s",s,_rcescape(a[j],1)) >> ofile
  }

  print ")" >> ofile
}

